# qpth • [![Build Status][travis-image]][travis] [![PyPi][pypi-image]][pypi] [![License][license-image]][license]

[travis-image]: https://travis-ci.org/locuslab/qpth.png?branch=master
[travis]: http://travis-ci.org/locuslab/qpth

[pypi-image]: https://img.shields.io/pypi/v/qpth.svg
[pypi]: https://pypi.python.org/pypi/qpth

[license-image]: http://img.shields.io/badge/license-Apache--2-blue.svg?style=flat
[license]: LICENSE

*A fast and differentiable QP solver for PyTorch.
Crafted by [Brandon Amos](http://bamos.github.io) and
[J. Zico Kolter](http://zicokolter.com).*

---

+ [More details are available on our project website here](http://locuslab.github.io/qpth)
